@@ -13,14 +13,10 @@ pub struct AtbashDecoder;
 impl Crack for Decoder<AtbashDecoder> {
     fn new() -> Decoder<AtbashDecoder> {
         Decoder {
-            name: "atbash",
+            name: "Atbash",
             description: "Atbash is a monoalphabetic substitution cipher originally used to encrypt the Hebrew alphabet. It can be modified for use with any known writing system with a standard collating order.",
             link: "https://en.wikipedia.org/wiki/Atbash",
-            tags: vec!["atbash", "substitution", "decoder"],
-            expected_runtime: 0.01,
-            expected_success: 1.0,
-            failure_runtime: 0.01,
-            normalised_entropy: vec![1.0, 10.0],
+            tags: vec!["atbash", "substitution", "decoder", "reciprocal"],
             popularity: 1.0,
             phantom: std::marker::PhantomData,
         }
@@ -51,6 +47,14 @@ impl Crack for Decoder<AtbashDecoder> {
 
         results
     }
+    /// Gets all tags for this decoder
+    fn get_tags(&self) -> &Vec<&str> {
+        &self.tags
+    }
+    /// Gets the name for the current decoder
+    fn get_name(&self) -> &str {
+        self.name
+    }
 }
 
 /// Maps atbash to the alphabet
