@@ -19,10 +19,6 @@ impl Crack for Decoder<MorseCodeDecoder> {
             description: "Morse code is a method used in telecommunication to encode text characters as standardized sequences of two different signal durations, called dots and dashes, or dits and dahs.",
             link: "https://en.wikipedia.org/wiki/Morse_code",
             tags: vec!["morseCode", "decoder", "signals"],
-            expected_runtime: 0.01,
-            expected_success: 1.0,
-            failure_runtime: 0.01,
-            normalised_entropy: vec![1.0, 10.0],
             popularity: 0.5,
             phantom: std::marker::PhantomData,
         }
@@ -61,6 +57,14 @@ impl Crack for Decoder<MorseCodeDecoder> {
 
         results
     }
+    /// Gets all tags for this decoder
+    fn get_tags(&self) -> &Vec<&str> {
+        &self.tags
+    }
+    /// Gets the name for the current decoder
+    fn get_name(&self) -> &str {
+        self.name
+    }
 }
 
 /// We want to remove new lines / line breaks so all the morse is on 1 line and we can parse it better
@@ -75,6 +79,7 @@ fn normalise_morse_string(text: &str) -> String {
 
 /// Maps morse code to its alphanumeric character, returns None for invalid morse-code
 fn morse_to_alphanumeric(text: &str) -> Option<&str> {
+    trace!("Starting to map morse code to alphanumeric");
     let result = match text {
         ".-" => "A",
         "-..." => "B",
@@ -132,6 +137,10 @@ fn morse_to_alphanumeric(text: &str) -> Option<&str> {
         "-.-.--" => "!",
         " " => " ",
         "" => "",
+        // Turns line breaks and new lines into space. This may break what the plaintext is supposed to be
+        // But enables us to support them
+        "\n" => " ",
+        "\r" => " ",
         _ => return None,
     };
 
