@@ -33,13 +33,7 @@ impl Crack for Decoder<ReverseDecoder> {
             name: "Reverse",
             description: "Reverses a string. stac -> cats",
             link: "http://string-functions.com/reverse.aspx",
-            tags: vec!["reverse", "decoder"],
-            /// We expect it to take 0.01 seconds to run
-            expected_runtime: 0.01,
-            expected_success: 1.0,
-            /// If it was to fail, we'd expect it to take 0.01 seconds
-            failure_runtime: 0.01,
-            normalised_entropy: vec![1.0, 10.0],
+            tags: vec!["reverse", "decoder", "reciprocal"],
             // I have never seen a reversed string in a CTF
             // or otherwise
             popularity: 0.2,
@@ -63,6 +57,14 @@ impl Crack for Decoder<ReverseDecoder> {
         result.update_checker(&checker_res);
         result
     }
+    /// Gets all tags for this decoder
+    fn get_tags(&self) -> &Vec<&str> {
+        &self.tags
+    }
+    /// Gets the name for the current decoder
+    fn get_name(&self) -> &str {
+        self.name
+    }
 }
 
 #[cfg(test)]
